==> node-typescript_2.1.4.orig.tar.gz: TypeScript-2.1.4/tests/cases/fourslash/server/jsdocTypedefTag.ts <==
/// <reference path="../fourslash.ts"/>

// @allowNonTsExtensions: true
// @Filename: jsdocCompletion_typedef.js

//// /** @typedef {(string | number)} NumberLike */
////
//// /**
////  * @typedef Animal
////  * @type {Object}
////  * @property {string} animalName
////  * @property {number} animalAge
////  */
////
//// /**
////  * @typedef {Object} Person
////  * @property {string} personName
////  * @property {number} personAge
////  */
////
//// /**
////  * @typedef {Object}
////  * @property {string} catName
////  * @property {number} catAge
////  */
//// var Cat;
////
//// /** @typedef {{ dogName: string, dogAge: number }} */
//// var Dog;
////
//// /** @type {NumberLike} */
//// var numberLike; numberLike./*numberLike*/
////
//// /** @type {Person} */
//// var p;p./*person*/;
//// p.personName./*personName*/;
//// p.personAge./*personAge*/;
////
//// /** @type {Animal} */
//// var a;a./*animal*/;
//// a.animalName./*animalName*/;
//// a.animalAge./*animalAge*/;
////
//// /** @type {Cat} */
//// var c;c./*cat*/;
//// c.catName./*catName*/;
//// c.catAge./*catAge*/;
////
//// /** @type {Dog} */
//// var d;d./*dog*/;
//// d.dogName./*dogName*/;
//// d.dogAge./*dogAge*/;

goTo.marker('numberLike');
verify.memberListContains('charAt');
verify.memberListContains('toExponential');

goTo.marker('person');
verify.memberListContains('personName');
verify.memberListContains('personAge');
goTo.marker('personName');
verify.memberListContains('charAt');
goTo.marker('personAge');
verify.memberListContains('toExponential');

goTo.marker('animal');
verify.memberListContains('animalName');
verify.memberListContains('animalAge');
goTo.marker('animalName');
verify.memberListContains('charAt');
goTo.marker('animalAge');
verify.memberListContains('toExponential');

goTo.marker('dog');
verify.memberListContains('dogName');
verify.memberListContains('dogAge');
goTo.marker('dogName');
verify.memberListContains('charAt');
goTo.marker('dogAge');
verify.memberListContains('toExponential');

goTo.marker('cat');
verify.memberListContains('catName');
verify.memberListContains('catAge');
goTo.marker('catName');
verify.memberListContains('charAt');
goTo.marker('catAge');
verify.memberListContains('toExponential');

==> node-typescript_2.7.2.orig.tar.gz: TypeScript-2.7.2/tests/cases/fourslash/server/jsdocTypedefTag.ts <==
/// <reference path="../fourslash.ts"/>

// @allowNonTsExtensions: true
// @Filename: jsdocCompletion_typedef.js

//// /** @typedef {(string | number)} NumberLike */
////
//// /**
////  * @typedef Animal
////  * @type {Object}
////  * @property {string} animalName
////  * @property {number} animalAge
////  */
////
//// /**
////  * @typedef {Object} Person
////  * @property {string} personName
////  * @property {number} personAge
////  */
////
//// /**
////  * @typedef {Object}
////  * @property {string} catName
////  * @property {number} catAge
////  */
//// var Cat;
////
//// /** @typedef {{ dogName: string, dogAge: number }} */
//// var Dog;
////
//// /** @type {NumberLike} */
//// var numberLike; numberLike./*numberLike*/
////
//// /** @type {Person} */
//// var p;p./*person*/;
//// p.personName./*personName*/;
//// p.personAge./*personAge*/;
////
//// /** @type {Animal} */
//// var a;a./*animal*/;
//// a.animalName./*animalName*/;
//// a.animalAge./*animalAge*/;
////
//// /** @type {Cat} */
//// var c;c./*cat*/;
//// c.catName./*catName*/;
//// c.catAge./*catAge*/;
////
//// /** @type {Dog} */
//// var d;d./*dog*/;
//// d.dogName./*dogName*/;
//// d.dogAge./*dogAge*/;

goTo.marker('numberLike');
verify.completionListContains('charAt');
verify.completionListContains('toExponential');

goTo.marker('person');
verify.completionListContains('personName');
verify.completionListContains('personAge');
goTo.marker('personName');
verify.completionListContains('charAt');
goTo.marker('personAge');
verify.completionListContains('toExponential');

goTo.marker('animal');
verify.completionListContains('animalName');
verify.completionListContains('animalAge');
goTo.marker('animalName');
verify.completionListContains('charAt');
goTo.marker('animalAge');
verify.completionListContains('toExponential');

goTo.marker('dog');
verify.completionListContains('dogName');
verify.completionListContains('dogAge');
goTo.marker('dogName');
verify.completionListContains('charAt');
goTo.marker('dogAge');
verify.completionListContains('toExponential');

goTo.marker('cat');
verify.completionListContains('catName');
verify.completionListContains('catAge');
goTo.marker('catName');
verify.completionListContains('charAt');
goTo.marker('catAge');
verify.completionListContains('toExponential');
